@@ -4,7 +4,7 @@ use auto_diff::optim::{SGD, MiniBatch};
 use auto_diff::Var;
 use rand::prelude::*;
 use ::rand::prelude::StdRng;
-
+extern crate openblas_src;
 
 //use tensorboard_rs::summary_writer::SummaryWriter;
 
@@ -35,7 +35,7 @@ fn main() {
     test_label.reset_net();
 
     let patch_size = 16;
-    let class_size = 10;
+    //let class_size = 10;
 
     // build the model
 //    let mut m = Module::new();
@@ -115,7 +115,7 @@ fn main() {
     op4.set_bias(Var::normal(&mut rng, &[10, ], 0., 1.));
 
 //    //println!("{}, {}", &train_data, &train_label);
-    let mut rng = StdRng::seed_from_u64(671);
+    let rng = StdRng::seed_from_u64(671);
     let mut minibatch = MiniBatch::new(rng, 16);
 
     //    let mut writer = SummaryWriter::new(&("./logdir".to_string()));
@@ -131,7 +131,7 @@ fn main() {
 
     let loss = output.cross_entropy_loss(&label).unwrap();  println!("here8");
     
-    let mut lr = 0.1;
+    let lr = 0.1;
     let mut opt = SGD::new(lr);
 
     println!("{:?}", loss);
