@@ -4,13 +4,14 @@ use auto_diff::optim::{SGD};
 use auto_diff::op::Linear;
 use auto_diff::op::OpCall;
 use auto_diff::err::AutoDiffError;
+extern crate openblas_src;
 
 fn main() {
 
     fn func(input: &Var) -> Result<Var, AutoDiffError> {
         let input = input.clone();
         input.set_grad(false);
-        let result = input.matmul(&Var::new(&vec![2., 3.], &vec![2, 1]))?.add(&Var::new(&vec![1.], &vec![1]))?;
+        let result = input.matmul(&Var::new(&vec![2., 3.], &vec![2, 1]))? + Var::new(&vec![1.], &vec![1]);
         result.set_grad(true);
         Ok(result)
     }
@@ -41,6 +42,4 @@ fn main() {
         let bias = op1.bias();
         println!("{:?}, {:?}", weight, bias);
     }
-
-    
 }
