@@ -1,12 +1,16 @@
-/// A generational index implementation.
-/// A generational index is a map-a-like container, which
-/// invalidate index/key when the item is removed,
-/// even the container itself don't have the access to that index/key.
+//! A generational index implementation.
+//! A generational index is a map-a-like container, which
+//! invalidate index/key when the item is removed,
+//! even the container itself don't have the access to that index/key.
 use std::fmt;
 
+#[cfg(feature = "use-serde")]
+use serde::{Serialize, Deserialize};
+
 use crate::err::AutoDiffError;
 
 /// GenKey index used for generational index.
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 #[derive(Debug, PartialEq, Eq, Ord, PartialOrd, Copy, Clone)]
 pub struct GenKey {
     id: usize,
@@ -29,6 +33,8 @@ impl fmt::Display for GenKey {
 /// The data is stored in a read-only manner,
 /// Use RefCell to get mutability.
 /// Not secure, no index validity check.
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
+#[derive(Clone)]
 pub struct GenIndex<T> {
     data: Vec<T>,
     generation: Vec<usize>,
@@ -102,23 +108,23 @@ impl<T> GenIndex<T> {
     }
 
     /// Remove an item from the list.
-    pub fn remove(&mut self, index: &GenKey) -> Result<(), ()> {
+    pub fn remove(&mut self, index: &GenKey) -> Result<(), AutoDiffError> {
         if index.id < self.generation.len() && self.generation[index.id] == index.gen {
             self.generation[index.id] += 1;
             self.available.push(index.id);
             Ok(())
         } else {
-            Err(())
+            Err(AutoDiffError::new(&format!("index is not valid! {}", index)))
         }
     }
 
     /// Replace the item of the index with a new one.
-    pub fn replace(&mut self, index: &GenKey, val: T) -> Result<(), ()> {
+    pub fn replace(&mut self, index: &GenKey, val: T) -> Result<(), AutoDiffError> {
         if index.id < self.data.len() && self.generation[index.id] == index.gen {
             self.data[index.id] = val;
             Ok(())
         } else {
-            Err(())
+            Err(AutoDiffError::new(&format!("index is not valid! {}", index)))
         }
     }
 
@@ -143,7 +149,7 @@ impl<'a, T> GenIndexIter<'a, T> {
 impl<'a, T> Iterator for GenIndexIter<'a, T> {
     type Item = GenKey;
     
-    fn next(&mut self) -> Option<GenKey> {
+    fn next(&mut self) -> Option<GenKey> { // TODO: don't return Option<GenKey>, return Option<&GenKey>
         let ret: GenKey;
         if self.gen_index_ref.data.is_empty() {
             return None;
@@ -181,6 +187,34 @@ impl<T> Default for GenIndex<T> {
     }
 }
 
+impl<T: PartialEq> PartialEq for GenIndex<T> {
+    fn eq(&self, other: &Self) -> bool {
+	if self.len() != other.len() {
+	    false
+	} else {
+	    for (self_key, other_key) in
+		self.iter_key().zip(other.iter_key()) {
+		    if ! self.get(&self_key).expect("GenIndex bad").eq(
+			other.get(&other_key).expect("GenIndex bad")) {
+			return false;
+		    }
+		}
+	    true
+	}
+    }
+}
+
+impl<T: Eq> Eq for GenIndex<T> {}
+
+impl<T: fmt::Debug> fmt::Debug for GenIndex<T> {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+	writeln!(f, "generation: {:?}", self.generation)?;
+	writeln!(f, "available: {:?}", self.available)?;
+	writeln!(f, "data: {:?}", self.data)
+    }
+}
+
+
 
 #[cfg(test)]
 mod tests {
