@@ -1,7 +1,14 @@
 use tensor_rs::tensor::Tensor;
 use super::{OpTrait, OpHandle};
 
+#[cfg(feature = "use-serde")]
+use serde::{Serialize, Deserialize};
+#[cfg(feature = "use-serde")]
+use std::any::Any;
+
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct NormalizeUnit {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
 }
 impl NormalizeUnit {
@@ -19,8 +26,8 @@ impl NormalizeUnit {
 }
 impl OpTrait for NormalizeUnit {
      
-    fn get_name(&self) -> String {
-        "normalize_unit".to_string()
+    fn get_name(&self) -> &'static str {
+        "NormalizeUnit"
     }
     fn get_input_size(&self) -> usize {
         1
@@ -42,6 +49,10 @@ impl OpTrait for NormalizeUnit {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 impl Default for NormalizeUnit {
     fn default() -> Self {
@@ -50,7 +61,9 @@ impl Default for NormalizeUnit {
 }
 
 
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct Det {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
 }
 impl Det {
@@ -68,8 +81,8 @@ impl Det {
 }
 impl OpTrait for Det {
      
-    fn get_name(&self) -> String {
-        "det".to_string()
+    fn get_name(&self) -> &'static str {
+        "Det"
     }
     fn get_input_size(&self) -> usize {
         1
@@ -91,6 +104,10 @@ impl OpTrait for Det {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 impl Default for Det {
     fn default() -> Self {
@@ -98,7 +115,9 @@ impl Default for Det {
     }
 }
 
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct Inv {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
 }
 impl Inv {
@@ -116,8 +135,8 @@ impl Inv {
 }
 impl OpTrait for Inv {
      
-    fn get_name(&self) -> String {
-        "inv".to_string()
+    fn get_name(&self) -> &'static str {
+        "Inv"
     }
     fn get_input_size(&self) -> usize {
         1
@@ -139,6 +158,10 @@ impl OpTrait for Inv {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 impl Default for Inv {
     fn default() -> Self {
@@ -146,7 +169,9 @@ impl Default for Inv {
     }
 }
 
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct Tr {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
 }
 impl Tr {
@@ -164,8 +189,8 @@ impl Tr {
 }
 impl OpTrait for Tr {
      
-    fn get_name(&self) -> String {
-        "tr".to_string()
+    fn get_name(&self) -> &'static str {
+        "Tr"
     }
     fn get_input_size(&self) -> usize {
         1
@@ -187,6 +212,10 @@ impl OpTrait for Tr {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 impl Default for Tr {
     fn default() -> Self {
