@@ -2,7 +2,9 @@
 
 macro_rules! one_to_1_op_with_paras {
     ($a:ident, $b:expr, $is:expr,$os:expr, $c:ident, $d: tt, $( $arg_name:ident : $ArgTy:ty ),* $(,)?) => {
+	#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
         pub struct $a {
+	    #[cfg_attr(feature = "use-serde", serde(skip))]
             handle: OpHandle,
             $( $arg_name : $ArgTy ),*
         }
@@ -34,8 +36,8 @@ macro_rules! one_to_1_op_with_paras {
         }
         impl OpTrait for $a {
      
-            fn get_name(&self) -> String {
-                ($b).to_string()
+            fn get_name(&self) -> &'static str {
+                ($b)
             }
             fn get_input_size(&self) -> usize {
                 $is
@@ -57,13 +59,19 @@ macro_rules! one_to_1_op_with_paras {
             }
             fn set_values(&self, _v: &[Tensor]) {
             }
+	    #[cfg(feature = "use-serde")]
+	    fn as_any(&self) -> &dyn Any {
+		self
+	    }
         }
     }
 }
 
 macro_rules! many_to_1_op_with_paras {
     ($a:ident, $b:expr, $is:expr,$os:expr, $c:ident, $d: tt, $( $arg_name:ident : $ArgTy:ty ),* $(,)?) => {
+	#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
         pub struct $a {
+	    #[cfg_attr(feature = "use-serde", serde(skip))]
             handle: OpHandle,
             $( $arg_name : $ArgTy ),*
         }
@@ -95,8 +103,8 @@ macro_rules! many_to_1_op_with_paras {
         }
         impl OpTrait for $a {
      
-            fn get_name(&self) -> String {
-                ($b).to_string()
+            fn get_name(&self) -> &'static str {
+                ($b)
             }
             fn get_input_size(&self) -> usize {
                 $is
@@ -118,13 +126,19 @@ macro_rules! many_to_1_op_with_paras {
             }
             fn set_values(&self, _v: &[Tensor]) {
             }
+	    #[cfg(feature = "use-serde")]
+	    fn as_any(&self) -> &dyn Any {
+		self
+	    }
         }
     }
 }
 
 macro_rules! one_to_vec_op_with_paras {
     ($a:ident, $b:expr, $is:expr,$os:expr, $c:ident, $d: tt, $( $arg_name:ident : $ArgTy:ty ),* $(,)?) => {
+	#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
         pub struct $a {
+	    #[cfg_attr(feature = "use-serde", serde(skip))]
             handle: OpHandle,
             $( $arg_name : $ArgTy ),*
         }
@@ -156,8 +170,8 @@ macro_rules! one_to_vec_op_with_paras {
         }
         impl OpTrait for $a {
      
-            fn get_name(&self) -> String {
-                ($b).to_string()
+            fn get_name(&self) -> &'static str {
+                ($b)
             }
             fn get_input_size(&self) -> usize {
                 $is
@@ -182,13 +196,19 @@ macro_rules! one_to_vec_op_with_paras {
             }
             fn set_values(&self, _v: &[Tensor]) {
             }
+	    #[cfg(feature = "use-serde")]
+	    fn as_any(&self) -> &dyn Any {
+		self
+	    }
         }
     }
 }
 
 macro_rules! new_binary_op {
     ($a:ident, $b:expr, $c:tt, $d: tt) => {
+	#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
         pub struct $a {
+	    #[cfg_attr(feature = "use-serde", serde(skip))]
             handle: OpHandle,
         }
         impl $a {
@@ -206,8 +226,8 @@ macro_rules! new_binary_op {
         }
         impl OpTrait for $a {
      
-            fn get_name(&self) -> String {
-                ($b).to_string()
+            fn get_name(&self) -> &'static str {
+                ($b)
             }
             fn get_input_size(&self) -> usize {
                 2
@@ -229,6 +249,10 @@ macro_rules! new_binary_op {
             }
             fn set_values(&self, _v: &[Tensor]) {
             }
+	    #[cfg(feature = "use-serde")]
+	    fn as_any(&self) -> &dyn Any {
+		self
+	    }
         }
         impl Default for $a {
             fn default() -> Self {
@@ -240,7 +264,9 @@ macro_rules! new_binary_op {
 
 macro_rules! new_element_op {
     ($a:ident, $b:expr, $c:ident, $d: tt) => {
+	#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
         pub struct $a {
+	    #[cfg_attr(feature = "use-serde", serde(skip))]
             handle: OpHandle,
         }
         impl $a {
@@ -258,8 +284,8 @@ macro_rules! new_element_op {
         }
         impl OpTrait for $a {
      
-            fn get_name(&self) -> String {
-                ($b).to_string()
+            fn get_name(&self) -> &'static str {
+                ($b)
             }
             fn get_input_size(&self) -> usize {
                 2
@@ -281,6 +307,10 @@ macro_rules! new_element_op {
             }
             fn set_values(&self, _v: &[Tensor]) {
             }
+	    #[cfg(feature = "use-serde")]
+	    fn as_any(&self) -> &dyn Any {
+		self
+	    }
         }
         impl Default for $a {
             fn default() -> Self {
