@@ -7,7 +7,14 @@ use std::rc::Rc;
 use crate::var::{Var};
 use crate::err::AutoDiffError;
 
+#[cfg(feature = "use-serde")]
+use serde::{Serialize, Deserialize};
+#[cfg(feature = "use-serde")]
+use std::any::Any;
+
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct GetPatch {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
     range: Vec<(usize, usize)>,
     step: Option<Vec<usize>>,
@@ -46,8 +53,8 @@ impl OpCall for GetPatch {
 }
 impl OpTrait for GetPatch {
 
-    fn get_name(&self) -> String {
-        "get_patch".to_string()
+    fn get_name(&self) -> &'static str {
+        "GetPatch"
     }
     fn get_input_size(&self) -> usize {
         1
@@ -70,10 +77,15 @@ impl OpTrait for GetPatch {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 
-
+#[cfg_attr(feature = "use-serde", derive(Serialize, Deserialize))]
 pub struct SetPatch {
+    #[cfg_attr(feature = "use-serde", serde(skip))]
     handle: OpHandle,
     range: Vec<(usize, usize)>,
     step: Option<Vec<usize>>,
@@ -113,8 +125,8 @@ impl OpCall for SetPatch {
 }
 impl OpTrait for SetPatch {
 
-    fn get_name(&self) -> String {
-        "set_patch".to_string()
+    fn get_name(&self) -> &'static str {
+        "SetPatch"
     }
     fn get_input_size(&self) -> usize {
         2
@@ -137,6 +149,10 @@ impl OpTrait for SetPatch {
     }
     fn set_values(&self, _v: &[Tensor]) {
     }
+    #[cfg(feature = "use-serde")]
+    fn as_any(&self) -> &dyn Any {
+	self
+    }
 }
 
 
